@@ -59,10 +59,13 @@ class Engine:
     if self.optimizer== "BL":
       self.weights = bl(self, perf="False")
       
-    if self.rebalance!=None and self.optimizer !="BL":
+    if self.rebalance!=None & self.optimizer !="BL":
       self.rebalance = make_rebalance(self.start_date, self.end_date, self.optimizer, self.portfolio, self.rebalance, self.max_vol, self.weights)
 
-    if self.rebalance!=None and self.optimizer=="BL" and self.optimizer==None:
+    if self.rebalance!=None & self.optimizer=="BL":
+      self.rebalance = make_rebalance(self.start_date, self.end_date, False, self.portfolio, self.rebalance, self.max_vol, self.weights)
+
+    if self.rebalance!=None & self.optimizer==None:
       self.rebalance = make_rebalance(self.start_date, self.end_date, False, self.portfolio, self.rebalance, self.max_vol, self.weights)
     
 #-------------------------------------------------------------------------------------------
